// src/use-snippet.ts
import { snippet } from "@nextui-org/theme";
import { mapPropsVariants } from "@nextui-org/system";
import { useDOMRef } from "@nextui-org/dom-utils";
import { clsx, dataAttr } from "@nextui-org/shared-utils";
import { useClipboard } from "@nextui-org/use-clipboard";
import { useFocusRing } from "@react-aria/focus";
import { useMemo, useCallback } from "react";
import { usePress } from "@react-aria/interactions";
import { mergeProps } from "@react-aria/utils";
function useSnippet(originalProps) {
  const [props, variantProps] = mapPropsVariants(originalProps, snippet.variantKeys);
  const {
    ref,
    as,
    children,
    symbol = "$",
    classNames,
    timeout,
    copyIcon,
    checkIcon,
    disableCopy = false,
    disableTooltip = false,
    hideCopyButton = false,
    autoFocus = false,
    hideSymbol = false,
    onCopy: onCopyProp,
    tooltipProps = {
      offset: 15,
      delay: 1e3,
      content: "Copy to clipboard",
      variant: originalProps == null ? void 0 : originalProps.variant,
      color: originalProps == null ? void 0 : originalProps.color,
      isDisabled: disableCopy
    },
    className,
    ...otherProps
  } = props;
  const Component = as || "div";
  const domRef = useDOMRef(ref);
  const { copy, copied } = useClipboard({ timeout });
  const isMultiLine = children && Array.isArray(children);
  const { isFocusVisible, isFocused, focusProps } = useFocusRing({
    autoFocus
  });
  const slots = useMemo(
    () => snippet({
      ...variantProps
    }),
    [...Object.values(variantProps)]
  );
  const symbolBefore = useMemo(() => {
    if (!symbol || typeof symbol !== "string")
      return symbol;
    const str = symbol.trim();
    return str ? `${str} ` : "";
  }, [symbol]);
  const baseStyles = clsx(classNames == null ? void 0 : classNames.base, className);
  const getSnippetProps = useCallback(
    () => ({
      className: slots.base({
        class: baseStyles
      }),
      ...otherProps
    }),
    [slots, baseStyles, isMultiLine, otherProps]
  );
  const onCopy = useCallback(() => {
    if (disableCopy) {
      return;
    }
    let value = "";
    if (typeof children === "string") {
      value = children;
    } else if (Array.isArray(children)) {
      value = children.join("\n");
    }
    copy(value);
    onCopyProp == null ? void 0 : onCopyProp(value);
  }, [copy, disableCopy, onCopyProp, children]);
  const { isPressed: isCopyPressed, pressProps: copyButtonPressProps } = usePress({
    isDisabled: disableCopy,
    onPress: onCopy
  });
  const getCopyButtonProps = useCallback(
    (props2 = {}) => ({
      ...mergeProps(copyButtonPressProps, focusProps, props2),
      "data-focus": dataAttr(isFocused),
      "data-focus-visible": dataAttr(isFocusVisible),
      "data-pressed": dataAttr(isCopyPressed),
      className: slots.copy({
        class: clsx(disableCopy && "opacity-50 cursor-not-allowed", classNames == null ? void 0 : classNames.copy)
      })
    }),
    [
      slots,
      isCopyPressed,
      isFocusVisible,
      isFocused,
      disableCopy,
      classNames == null ? void 0 : classNames.copy,
      copyButtonPressProps,
      focusProps
    ]
  );
  return {
    Component,
    as,
    domRef,
    children,
    slots,
    classNames,
    copied,
    onCopy,
    copyIcon,
    checkIcon,
    symbolBefore,
    isMultiLine,
    isFocusVisible,
    hideCopyButton,
    disableCopy,
    disableTooltip,
    hideSymbol,
    tooltipProps,
    getSnippetProps,
    getCopyButtonProps
  };
}

export {
  useSnippet
};
